#
# spec file for package byte-buddy
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           byte-buddy
Version:        1.17.6
Release:        2.1
Summary:        Runtime code generation for the Java virtual machine
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://bytebuddy.net/
Source0:        https://github.com/raphw/%{name}/archive/refs/tags/%{name}-%{version}.tar.gz
Patch0:         0001-Avoid-bundling-asm.patch
BuildRequires:  fdupes
BuildRequires:  jurand
BuildRequires:  maven-local
BuildRequires:  mvn(codes.rafael.modulemaker:modulemaker-maven-plugin)
BuildRequires:  mvn(com.google.code.findbugs:jsr305)
BuildRequires:  mvn(net.java.dev.jna:jna)
BuildRequires:  mvn(net.java.dev.jna:jna-platform)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-annotations)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.apache.maven:maven-resolver-provider)
BuildRequires:  mvn(org.eclipse.aether:aether-api)
BuildRequires:  mvn(org.eclipse.aether:aether-util)
BuildRequires:  mvn(org.ow2.asm:asm) >= 9.7.1
BuildRequires:  mvn(org.ow2.asm:asm-commons)
BuildRequires:  mvn(org.sonatype.plexus:plexus-build-api)
BuildArch:      noarch

%description
Byte Buddy is a code generation and manipulation library for creating and
modifying Java classes during the runtime of a Java application and without the
help of a compiler. Other than the code generation utilities that ship with the
Java Class Library, Byte Buddy allows the creation of arbitrary classes and is
not limited to implementing interfaces for the creation of runtime proxies.
Furthermore, Byte Buddy offers a convenient API for changing classes either
manually, using a Java agent or during a build.

%package agent
Summary:        Byte Buddy Java agent
Group:          Development/Libraries/Java

%description agent
The Byte Buddy Java agent allows to access the JVM's HotSwap feature.

%package maven-plugin
Summary:        Byte Buddy Maven plugin
Group:          Development/Libraries/Java

%description maven-plugin
A plugin for post-processing class files via Byte Buddy in a Maven build.

%package javadoc
Summary:        API documentation for %{name}
Group:          Documentation/HTML

%description javadoc
API documentation for %{name}.

%prep
%setup -q -n %{name}-%{name}-%{version}
%patch -P0 -p1

# Remove Windows-specific resources
rm -rf %{name}-agent/src/main/resources/win32-x86{,-64}

# Don't ship android or benchmark modules
%pom_disable_module %{name}-android
%pom_disable_module %{name}-android-test
%pom_disable_module %{name}-benchmark

# Don't ship gradle plugin
%pom_disable_module %{name}-gradle-plugin

# Remove check plugins unneeded by RPM builds
%pom_remove_plugin :jacoco-maven-plugin
%pom_remove_plugin :license-maven-plugin
%pom_remove_plugin :pitest-maven
%pom_remove_plugin :coveralls-maven-plugin
%pom_remove_plugin :spotbugs-maven-plugin
%pom_remove_plugin :jitwatch-jarscan-maven-plugin
%pom_remove_plugin :maven-release-plugin
%pom_remove_plugin org.sonatype.central:central-publishing-maven-plugin
%pom_remove_plugin -r :maven-javadoc-plugin

# Avoid circular dependency
%pom_remove_plugin :byte-buddy-maven-plugin %{name}-dep

# Not interested in shading sources (causes NPE on old versions of shade plugin)
%pom_xpath_set pom:createSourcesJar false %{name}

# Drop build dep on findbugs annotations, used only by the above check plugins
%pom_remove_dep -r :findbugs-annotations
%{java_remove_annotations} %{name}-{agent,dep,maven-plugin} -n SuppressFBWarnings

%pom_remove_dep org.ow2.asm:asm-deprecated
%pom_remove_dep codes.rafael.asmjdkbridge:asm-jdk-bridge %{name}-dep

%pom_remove_plugin -r :maven-shade-plugin

%pom_add_dep org.apache.maven:maven-resolver-provider:\${version.maven}:provided \
    byte-buddy-maven-plugin

%{mvn_package} :byte-buddy-parent __noinstall

%build
%{mvn_build} -f -s -- \
    -Dsource=8

%install
%mvn_install
%if %{without bootstrap}
%fdupes -s %{buildroot}%{_javadocdir}
%endif

%files -f .mfiles-%{name} -f .mfiles-%{name}-dep
%doc README.md release-notes.md
%license LICENSE NOTICE

%files agent -f .mfiles-%{name}-agent
%license LICENSE NOTICE

%files maven-plugin -f .mfiles-%{name}-maven-plugin

%files javadoc -f .mfiles-javadoc
%license LICENSE NOTICE

%changelog
* Mon Jun 23 2025 Fridrich Strba <fstrba@suse.com>
- Fix build with maven 4
* Mon Jun 16 2025 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.17.6
  * Changes of v1.17.6
    + Add convenience wrapper for ResettableClassFileTransformer
    that implicitly delegates to correct transformer method.
    + Add filter for deduplicate fields and methods in class file.
    + Add missing static requirement of Spotbugs annotations to
    module descriptors.
    + Add LazinessMode for TypePool and add convenience support to
    AgentBuilder.
    + Fix source jars for multi-version release to contain
    duplicated source.
* Wed Apr  2 2025 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.17.5
  * Changes of v1.17.5
    + Update ASM to version 9.8 to support Java 25 using ASM reader
    and writer.
    + Include AnnotationRemoval visitor for removing or replacing
    annotations.
* Mon Mar 24 2025 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.17.4
  * Changes of v1.17.4
    + Add SafeVarargs plugin.
    + Fix OSGi declaration for byte-buddy-agent.
* Sat Mar 22 2025 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.17.3
  * Changes of v1.17.3
    + Fix bug in ASM to Class File API bridge handling tableswitch
    instructions.
    + Add plugin for adding SafeVarargs annotations.
    + Further generify MemberSubstitution API.
* Tue Mar  4 2025 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.17.2
  * Changes of v1.17.2
    + Update Class File API integration to include support for
    several omitted byte codes.
    + Adjust attach API emulation for OpenJ9 to not create
    subfolder if temporary folder is set explicitly.
* Fri Feb 14 2025 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.17.1
  * Changes of v1.17.1
    + Fix bug in MemberSubstitution were argument indices were
    resolved by one digit off.
    + Update Class File API integration to avoid that parameter
    annotations are lost.
* Wed Jan 29 2025 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.17.0
  * Changes of v1.17.0
    + Assure that implicit choice for class reader and class writer
    are always symmetric with regard to internal representation.
    + Retrofit MemberSubstitution to also allow for intercepting
    invokedynamic instructions.
    + Introduce @Handle annotations to allow for injecting constant
    pool-stored method handle in Advice, MemberSubstitution and
    MethodDelegation.
    + Introduce @DynamicConstant annotations to allow for injecting
    constant pool-stored dynamic constants in Advice,
    MemberSubstitution and MethodDelegation.
* Sun Jan 19 2025 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.16.1
  * Changes of v1.16.1
    + Correct reflective activation of Class File API.
    + Reject array descriptors that are not well-formed in
    TypePool.
* Sat Jan 18 2025 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.16.0
  * Changes of v1.16.0
    + Allow for erasure of types of bootstrapped methods in Advice
    within instrumented class.
    + Rework Advice post-processing to allow for erasure of
    bootstrapped methods.
    + Fix missing application of hashCode/equals plugin for Java 8
    code.
    + Include support for JDK Class File API.
    + Allow Plugin.Engine to retain folders.
- Rebase/update patch:
  * 0001-Avoid-bundling-asm.patch
* Sun Dec 15 2024 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.15.11
  * Changes of v1.15.11
    + Avoid dependency of CachedReturnPlugin on precompiled class
    files.
    + Add NOP instruction when Advice is used on void methods as
    those might be empty which results on a frame being written
    to the same offset, causing an exception.
    + Allow Plugin.Enging to link files instead of copying.
    + Adjust validator code to avoid compiler bug that was reported
    by multiple users.
    + Allow injection of class path as File[] to Plugin
    constructors.
    + Allow for configuring variants when using the Android Gradle
    plugin.
* Sun Nov  3 2024 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.15.10
  * Changes of v1.15.10
    + Fix Java 8 patterns for multi-release jars to avoid that
    inner classes are excluded.
  * Changes of v1.15.9
    + Additional release after time out during previous Gradle
    plugin release.
* Sat Nov  2 2024 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.15.8
  * Changes of v1.15.8
    + Extend ClassInjector API to support lazy resolution of class
    files.
    + Extend DynamicType API to support lazy resolution of
    auxiliary types.
    + Extend AgentBuilder.Transformer.ForAdvice to support
    injection of new classes by their name.
* Wed Oct 23 2024 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.15.7
  * Changes of v1.15.7
    + Additional release after time out during previous Gradle
    plugin release.
  * Changes of v1.15.6
    + Add ConstructorResolver to Super annotation for
    MethodDelegation to allow for dynamic constructor resolution.
    + Add Java 8 versions of shaded ASM to allow for faster class
    file validation and CDS support.
* Thu Oct 17 2024 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.15.5
  * Changes of v1.15.5
    + Publish Byte Buddy and Byte Buddy agent artifacts as
    multi-release jars to support CDS and faster validation.
- Remove Windows-specific resources
* Sat Oct 12 2024 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.15.4
  * Add non-experimental support for Java 24.
* Thu Sep 26 2024 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.15.3
  * Changes of v1.15.3
    + Treat multi-release class files that are newer than the
    supported version as regular resources.
    + Allow overriding the multi-release class file version from
    Maven and Gradle plugin.
    + Correctly resolve multi-release class files in Android.
* Wed Sep 25 2024 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.15.2
  * Changes of v1.15.2
    + Add support for multi-release JAR files in ClassFileLocators
    and Plugin.Engine.Default.
    + Add Gradle task for transforming multiple jar files with
    ByteBuddyJarsTask.
    + Avoid validation of JarFile when extracting individual
    entries.
    + Rework discovery in ByteBuddyMojo.
* Sun Sep  1 2024 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.15.1
  * Changes of v1.15.1
    + Revert default EntryPoint for Android Gradle plugin to use
    DECORATE unless explicitly specified due to many generic type
    errors in Kotlin classes.
  * Changes of v1.15.0
    + Introduce AsmClassWriter and AsmClassReader abstractions that
    allow for plugging different implementations of readers and
    writers.
    + Add configuration extension to the Android Gradle plugin and
    make it behave like regular Gradle plugin with standard
    configuration.
    + Throw TypeNotPresentException upon discovering undeclared
    type variables as it was recently fixed on the JVM.
  * Changes of v1.14.19
    + Add Maven Mojo for transforming jars and for transforming
    dependencies folder.
    + Better error handling for unresolved type variables.
    + Allow loading arguments of the instrumented method in
    MemberSubstitution.
    + Fix checks for method visibility.
* Mon Jul  8 2024 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.14.18
  * Changes of v1.14.18
    + Avoid verification error if constructor advice meats dropped
    implicit this frame and throw exception during
    instrumentation instead.
    + Add support to resolve ByteBuddyAgent from non-obfuscated
    name if obfuscation is used.
    + Make sure CircularityLock implementations never load classes
    during locking.
    + Offer use of istat if stat command is not available for
    emulated attachment.
    + Avoid locking entire class loader when child-first class
    loader loads shadowed class and parallel class loading is
    supported.
  * Changes of v1.14.17
    + Avoid crashing of Android plugin when there are duplicate
    files for licenses or license notices.
* Thu May 23 2024 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.14.16
  * Changes of v1.14.16
    + Update ASM and introduce support for Java 23.
* Tue May 21 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to v1.14.15
  * Changes of v1.14.15
    + Allow attaching from root on J9.
  * Changes of v1.14.14
    + Adjust type validation to accept additional names that are
    legal in the class file format.
    + Fix dynamic attach on Windows when a service user is active.
    + Avoid failure when using Android's strict mode.
- Removed patch:
  * 0002-Remove-dependencies.patch
    + not needed since we have jna packaged
* Thu Apr 18 2024 Fridrich Strba <fstrba@suse.com>
- Split the whole package into sub-packages
- Added patch:
  * 0001-Avoid-bundling-asm.patch
    + Do not bundle asm, but use external artifact
  * 0002-Remove-dependencies.patch
    + Remove optional dependency on jna
* Thu Mar 28 2024 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.14.13
  * Changes of v1.14.13
    + Avoid resolving type variables when generic type processing
    is disabled.
    + Improve error message for Byte Buddy agent external attach.
    + Fix build for modular jars when using later version than Java
    8.
* Sat Feb 17 2024 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.14.12
  * Changes of v1.14.12
    + Pin proxy class file version to avoid implicit changes when
    using Graal native image.
    + Add support for Java 23.
    + Add missing @MaybeNull annotation.
* Thu Dec 21 2023 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.14.11
  * Changes of v1.14.11
    + Adjusts Gradle plugin to support Gradle 8.4 without warnings.
    + Avoid blurry exception on build plugin for fail fast.
* Wed Dec 20 2023 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.14.10
  * Changes of v1.14.10
    + Add lazy facade to default TypePool in AgentBuilder to avoid
    parsing of types ignored by name.
    + Avoid module info classes in Android plugin.
* Tue Oct 17 2023 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.14.9
  * Changes of v1.14.9
    + Update ASM to version 9.6
    + Support Android plugin to support APG version 7.4
* Wed Sep 27 2023 Fridrich Strba <fstrba@suse.com>
- Remove dependency on findbugs
- Do not produce bootstrap package
* Thu Sep 14 2023 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.14.8
  * Changes of v1.14.8
    + Correctly read versions from class file that would use both
    bytes.
    + Fix Byte Buddy Gradle plugin for Gradle 8.3+.
    + Correct field and static method access on subtypes in
    MemberSubstitution.
    + Support APK 7.4+ versions in Byte Buddy Gradle for Android
    plugin.
- Reproducible builds: use SOURCE_DATE_EPOCH for timestamp
* Thu Aug 31 2023 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.14.7
  * Changes of v1.14.7
    + Correctly read minor version from class file.
    + Catch type resolution errors when applying Plugin.Engine.
* Tue Aug 15 2023 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.14.6
  * Changes of v1.14.6
    + Add PatchMode.SUBSTITUTE and
    ResettableClassFileTransformer.Substitutable for in-order
    patching.
    + Allow for explicit specification og differential matcher when
    patching an AgentBuilder.
    + Add platform loader to locator for build plugins.
    + Correctly resolve accessors for fields with capitalized first
    letter.
    + Make jars for Android read-only as newer versions require it.
* Sat Jun 10 2023 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.14.5
  * Changes of v1.14.5
    + Avoid use of location if agent argument separator is
    contained.
    + Allow failure of member substitution if no element is
    separated.
    + Allow retry in case of parallel class injection.
* Fri May  5 2023 Fridrich Strba <fstrba@suse.com>
- Do not bootstrap using downloaded binaries, but build the
  minimal bootstrap package from sources
* Thu Apr 13 2023 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.14.4
  * Changes of v1.14.4
    + Include instrumented type and auxiliary types in TypePool
    that is passed to TypeWriter.
* Mon Apr  3 2023 Anton Shvetz <shvetz.anton@gmail.com>
- Remove patch:
  * 00-asm5.patch - not needed due to update of objectweb-asm
* Sun Apr  2 2023 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.14.3
  * Changes of v1.14.3
    + Make MethodGraph.Compiler failsafe when processing incomplete
    methods.
    + Update ASM.
* Mon Mar 20 2023 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.14.2
  * Changes of v1.14.2
    + Fix offset mapping for local variable array remapping in
    Advice.
    + Add possibility to specify an index for skipOn and repeatOn
    which resolves the checked value from a returned array.
  * Changes of 1.14.1
    + Add extended scope for Maven Byte Buddy plugin to include all
    non-test-dependencies.
* Wed Mar  8 2023 Anton Shvetz <shvetz.anton@gmail.com>
- Initial packaging with v1.14.0
- Add patch:
  * 00-asm5.patch
    ~ asm5 does not support the Opcodes.V20 constant
